@@ -3,7 +3,7 @@ package XML::Malware;
 use strict;
 use warnings;
 
-our $VERSION = '0.00_02';
+our $VERSION = '0.00_04';
 $VERSION = eval $VERSION;  # see L<perlmodstyle>
 
 use XML::Compile;
@@ -30,13 +30,16 @@ sub new {
 sub in {
     my $self = shift;
     my $xml = shift;
-    return undef (unless($xml));
+    return(undef) unless($xml);
 
     my $s = XML::Compile::Schema->new();
     $s->importDefinitions(MYNS);
 
     my $read = $s->compile(READER => $type);
-    return($read->($xml));
+    my $h = $read->($xml);
+    return(undef) unless($h && ref($h) eq 'HASH');
+    $self->_hash($h);
+    return($self->_hash());
 }
 
 sub out {
